@@ -1,4 +1,4 @@
-## Copyright 2012 Sebastian Gibb
+## Copyright 2012-2015 Sebastian Gibb
 ## <mail@sebastiangibb.de>
 ##
 ## This file is part of MALDIquantForeign for R and related languages.
@@ -16,17 +16,17 @@
 ## You should have received a copy of the GNU General Public License
 ## along with MALDIquantForeign. If not, see <http://www.gnu.org/licenses/>
 
-#' @keywords internal
 .importMzXml <- function(file, centroided=FALSE, massRange=c(0, Inf),
                          minIntensity=0, verbose=FALSE, ...) {
 
   l <- readMzXmlData:::.readMzXmlFile(mzXmlFile=file,
                                       verbose=verbose, ...)
-  return(lapply(l, function(x).createMassObject(data=x$spectrum,
-                                                metaData=x$metaData,
-                                                centroided=centroided,
-                                                massRange=massRange,
-                                                minIntensity=minIntensity,
-                                                verbose=verbose)))
+  lapply(l, function(x).createMassObject(mass=x$spectrum$mass,
+                                         intensity=x$spectrum$intensity,
+                                         snr=x$spectrum$snr,
+                                         metaData=x$metaData,
+                                         centroided=centroided,
+                                         massRange=massRange,
+                                         minIntensity=minIntensity,
+                                         verbose=verbose))
 }
-
