@@ -50,7 +50,7 @@
 #' @author Sebastian Gibb \email{mail@@sebastiangibb.de}
 #' @references
 #' Definition of \code{mzML} format:
-#' \url{http://www.psidev.info/mzml_1_0_0}
+#' \url{http://www.psidev.info/mzml}
 #' @keywords internal
 #' @noRd
 .mzMlHandlers <- function(fileName, verbose=FALSE) {
@@ -201,6 +201,9 @@
     } else if (.isAttrSet(attrs, "MS:1000517", "signal to noise array")) {
       .setCvValue("snr", "currentArray")
       return()
+    } else if (.isAttrSet(attrs, "MS:1000786", "non-standard data array")) {
+      .setCvValue("nonstandard", "currentArray")
+      return()
     }
 
     ## IMS extensions
@@ -385,15 +388,15 @@
   }
 
   ## return statement (please call getData())
-  return(list(getData=function() {return(xml)},
-              mzML=mzML,
-              referenceableParamGroup=referenceableParamGroup,
-              referenceableParamGroupRef=referenceableParamGroupRef,
-              spectrumList=spectrumList,
-              spectrum=spectrum,
-              chromatogram=chromatogram,
-              cvParam=cvParam,
-              .startElement=.startElement,
-              .endElement=.endElement,
-              .text=.text))
+  list(getData=function() {return(xml)},
+       mzML=mzML,
+       referenceableParamGroup=referenceableParamGroup,
+       referenceableParamGroupRef=referenceableParamGroupRef,
+       spectrumList=spectrumList,
+       spectrum=spectrum,
+       chromatogram=chromatogram,
+       cvParam=cvParam,
+       .startElement=.startElement,
+       .endElement=.endElement,
+       .text=.text)
 }
